package atom

import (
	"encoding/xml"
	"errors"
	"fmt"
)

type XHTMLDiv struct {
	XMLName xml.Name `xml:"div"`
	XMLNS   string   `xml:"xmlns,attr"`
	Content string   `xml:",innerxml"`
}

// NewXHTMLDiv creates a new XHTMLDiv. It returns a *XHTMLDiv and an error.
func NewXHTMLDiv(content string) (*XHTMLDiv, error) {
	if content == "" {
		return nil, errors.New("error creating new xhtml div: content string empty")
	}

	return &XHTMLDiv{
		XMLNS:   "http://www.w3.org/1999/xhtml",
		Content: content,
	}, nil
}

// Check checks the XHTMLDiv for incompatibilities with RFC4287. It returns an
// error.
func (x *XHTMLDiv) Check() error {
	if x.XMLNS != "http://www.w3.org/1999/xhtml" {
		return fmt.Errorf("xmlns attribute of xhtml text %v must be http://www.w3.org/1999/xhtml", x)
	}

	return nil
}
