package atom

import (
	"fmt"
)

type XHTMLText struct {
	*CommonAttributes
	XHTMLDiv *XHTMLDiv
	Type     string `xml:"type,attr"` // Must be xhtml
}

// isText checks whether the XHTMLText is a Text. It returns a bool.
func (x *XHTMLText) isText() bool { return true }

// newPlainText creates a new PlainText. It returns a *PlainText and an error.
func newXHTMLText(textType, content string) (*XHTMLText, error) {
	xhtmlDiv, err := NewXHTMLDiv(content)
	if err != nil {
		return nil, fmt.Errorf("error creating new xhtml text: %v", err)
	}

	return &XHTMLText{
		Type:     textType,
		XHTMLDiv: xhtmlDiv,
	}, nil
}

// Check checks the XHTMLText for incompatibilities with RFC4287. It returns an
// error.
func (x *XHTMLText) Check() error {
	if x.Type != "xhtml" {
		return fmt.Errorf("type attribute of xhtml text %v must be xhtml", x)
	}

	if err := x.XHTMLDiv.Check(); err != nil {
		return fmt.Errorf("xhtml div element %v of xhtml text %v: %v", x.XHTMLDiv, x, err)
	}

	return nil
}
